# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`netplan`](#netplan): Install and configure netplan

### Defined types

* [`netplan::config`](#netplan--config): Generate netplan YAML files

## Classes

### <a name="netplan"></a>`netplan`

Manages the installation of netplan and controls global options like whether to purge unmanaged files.

#### Examples

##### Basic usage

```puppet
include netplan
```

##### Purge un-managed files

```puppet
class { netplan:
  purge_configs => true,
}
```

##### Purge un-managed files, but ignore a given pattern

```puppet
class { netplan:
  purge_configs => true,
  purge_ignore  => '90-NM*'
}
```

#### Parameters

The following parameters are available in the `netplan` class:

* [`package_dependencies`](#-netplan--package_dependencies)
* [`manage_dependencies`](#-netplan--manage_dependencies)
* [`apply`](#-netplan--apply)
* [`purge_configs`](#-netplan--purge_configs)
* [`purge_ignore`](#-netplan--purge_ignore)
* [`configs`](#-netplan--configs)

##### <a name="-netplan--package_dependencies"></a>`package_dependencies`

Data type: `Array`

List of packages to install

Default value: `['netplan.io']`

##### <a name="-netplan--manage_dependencies"></a>`manage_dependencies`

Data type: `Boolean`

Whether to install the list of package dependencies or not

Default value: `true`

##### <a name="-netplan--apply"></a>`apply`

Data type: `Boolean`

Whether to apply the netplan configuration during the agent run or not

Default value: `true`

##### <a name="-netplan--purge_configs"></a>`purge_configs`

Data type: `Boolean`

Whether to purge un-managed netplan YAML files under /etc/netplan

Default value: `false`

##### <a name="-netplan--purge_ignore"></a>`purge_ignore`

Data type: `Optional[String]`

Match files to ignore when purging configs under /etc/netplan.
Uses the `ignore` attribute of the native puppet `file` resource.

Default value: `undef`

##### <a name="-netplan--configs"></a>`configs`

Data type: `Optional[Hash]`

An optional hash of netplan configurations supplied via hiera

Default value: `undef`

## Defined types

### <a name="netplan--config"></a>`netplan::config`

Create netplan YAML files from a Hash of data.

#### Examples

##### Basic config

```puppet
netplan::config { 'example-config':
  settings => {
    version => 2,
    renderer => networkd,
    ethernets => {
      eth0 => {
        dhcp4 => true,
      },
    },
  },
}
```

#### Parameters

The following parameters are available in the `netplan::config` defined type:

* [`ensure`](#-netplan--config--ensure)
* [`file_name`](#-netplan--config--file_name)
* [`priority`](#-netplan--config--priority)
* [`file`](#-netplan--config--file)
* [`file_mode`](#-netplan--config--file_mode)
* [`header`](#-netplan--config--header)
* [`settings`](#-netplan--config--settings)

##### <a name="-netplan--config--ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Ensure presence/absence of the resource

Default value: `'present'`

##### <a name="-netplan--config--file_name"></a>`file_name`

Data type: `String`

The filename to use for the generated YAML file

Default value: `$title`

##### <a name="-netplan--config--priority"></a>`priority`

Data type: `Variant[String, Integer[0]]`

The string/number prefixed to the generated YAML file

Default value: `90`

##### <a name="-netplan--config--file"></a>`file`

Data type: `Stdlib::Absolutepath`

The absolute path of the genrated YAML file

Default value: `"/etc/netplan/${priority}-${file_name}.yaml"`

##### <a name="-netplan--config--file_mode"></a>`file_mode`

Data type: `String`

The file permissions for the generated YAML file

Default value: `'0600'`

##### <a name="-netplan--config--header"></a>`header`

Data type: `String`

The file header for the generated YAML file

Default value: `'# This file is managed by Puppet. DO NOT EDIT.'`

##### <a name="-netplan--config--settings"></a>`settings`

Data type: `Hash`

A hash of netplan settings to be included in the generated YAML file

Default value: `{}`

